#
# spec file for package rclone
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


Name:           rclone
Version:        1.47.0
Release:        lp150.2.3.1
Summary:        Rsync for cloud storage
License:        MIT
Group:          Productivity/Networking/Web/Utilities
Url:            https://rclone.org/
Source:         %{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  go >= 1.11

%description
rsync for cloud storage. rclone is a command line program to sync files and
directories to and from a wide variety of cloud storage providers, providing
various additional features.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          Productivity/Networking/Web/Utilities
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          Productivity/Networking/Web/Utilities
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%setup -q

%build
go build -o %{name} -mod=vendor -buildmode=pie

./%{name} genautocomplete bash completion.bash
./%{name} genautocomplete zsh  completion.zsh

%install
install -m0754 -D %{name} %{buildroot}%{_bindir}/%{name}
install -m0644 -D %{name}.1 %{buildroot}%{_mandir}/man1/%{name}.1

install -m0644 -D completion.bash %{buildroot}%{_datadir}/bash/%{name}
install -m0644 -D completion.zsh  %{buildroot}%{_datadir}/zsh/_%{name}

%fdupes %{buildroot}

%files
%defattr(-,root,root,-)
%doc MANUAL.md README.md RELEASE.md
%license COPYING
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*

%files bash-completion
%defattr(-,root,root)
%{_datadir}/bash/

%files zsh-completion
%defattr(-,root,root)
%{_datadir}/zsh/

%changelog
* Sun Jun  9 2019 Aleksa Sarai <asarai@suse.com>
- Update to version 1.47.0. boo#1137685
  - New backends
  - Backend for Koofr cloud storage service. (jaKa)
  - New Features
  - Resume downloads if the reader fails in copy (Nick Craig-Wood)
  - Use `--fast-list` for listing operations where it won't use more memory (Nick Craig-Wood)
  - Make `--files-from` traverse the destination unless `--no-traverse` is set (Nick Craig-Wood)
  - Make server side copy account bytes and obey `--max-transfer` (Nick Craig-Wood)
  - Add `--create-empty-src-dirs` flag and default to not creating empty dirs (ishuah)
  - Add client side TLS/SSL flags `--ca-cert`/`--client-cert`/`--client-key` (Nick Craig-Wood)
  - Implement `--suffix-keep-extension` for use with `--suffix` (Nick Craig-Wood)
  - serve dlna: Add connection manager service description to improve compatibility (Dan Walters)
  - lsf: Add 'e' format to show encrypted names and 'o' for original IDs (Nick Craig-Wood)
  - lsjson: Added `--files-only` and `--dirs-only` flags (calistri)
  - rc: Implement operations/publiclink the equivalent of `rclone link` (Nick Craig-Wood)
  - Bug Fixes
  - accounting: Fix total ETA when `--stats-unit bits` is in effect (Nick Craig-Wood)
  - Bash TAB completion
  - Use private custom func to fix clash between rclone and kubectl (Nick Craig-Wood)
  - Fix for remotes with underscores in their names (Six)
  - Fix completion of remotes (Florian Gamböck)
  - Fix autocompletion of remote paths with spaces (Danil Semelenov)
  - serve dlna: Fix root XML service descriptor (Dan Walters)
  - ncdu: Fix display corruption with Chinese characters (Nick Craig-Wood)
  - Add SIGTERM to signals which run the exit handlers on unix (Nick Craig-Wood)
  - rc: Reload filter when the options are set via the rc (Nick Craig-Wood)
  - VFS / Mount
  - Fix FreeBSD: Ignore Truncate if called with no readers and already the correct size (Nick Craig-Wood)
  - Read directory and check for a file before mkdir (Nick Craig-Wood)
  - Shorten the locking window for vfs/refresh (Nick Craig-Wood)
  - Azure Blob
  - Enable MD5 checksums when uploading files bigger than the "Cutoff" (Dr.Rx)
  - Fix SAS URL support (Nick Craig-Wood)
  - B2
  - Allow manual configuration of backblaze downloadUrl (Vince)
  - Ignore already_hidden error on remove (Nick Craig-Wood)
  - Ignore malformed `src_last_modified_millis` (Nick Craig-Wood)
  - Drive
  - Add `--skip-checksum-gphotos` to ignore incorrect checksums on Google Photos (Nick Craig-Wood)
  - Allow server side move/copy between different remotes. (Fionera)
  - Add docs on team drives and `--fast-list` eventual consistency (Nestar47)
  - Fix imports of text files (Nick Craig-Wood)
  - Fix range requests on 0 length files (Nick Craig-Wood)
  - Fix creation of duplicates with server side copy (Nick Craig-Wood)
  - Dropbox
  - Retry blank errors to fix long listings (Nick Craig-Wood)
  - FTP
  - Add `--ftp-concurrency` to limit maximum number of connections (Nick Craig-Wood)
  - Google Cloud Storage
  - Fall back to default application credentials (marcintustin)
  - Allow bucket policy only buckets (Nick Craig-Wood)
  - HTTP
  - Add `--http-no-slash` for websites with directories with no slashes (Nick Craig-Wood)
  - Remove duplicates from listings (Nick Craig-Wood)
  - Fix socket leak on 404 errors (Nick Craig-Wood)
  - Jottacloud
  - Fix token refresh (Sebastian Bünger)
  - Add device registration (Oliver Heyme)
  - Onedrive
  - Implement graceful cancel of multipart uploads if rclone is interrupted (Cnly)
  - Always add trailing colon to path when addressing items, (Cnly)
  - Return errors instead of panic for invalid uploads (Fabian Möller)
  - S3
  - Add support for "Glacier Deep Archive" storage class (Manu)
  - Update Dreamhost endpoint (Nick Craig-Wood)
  - Note incompatibility with CEPH Jewel (Nick Craig-Wood)
  - SFTP
  - Allow custom ssh client config (Alexandru Bumbacea)
  - Swift
  - Obey Retry-After to enable OVH restore from cold storage (Nick Craig-Wood)
  - Work around token expiry on CEPH (Nick Craig-Wood)
  - WebDAV
  - Allow IsCollection property to be integer or boolean (Nick Craig-Wood)
  - Fix race when creating directories (Nick Craig-Wood)
  - Fix About/df when reading the available/total returns 0 (Nick Craig-Wood)
- Add bash-completion and zsh-completion support.
* Thu Mar 14 2019 Marcus Rueckert <mrueckert@suse.de>
- bump required go to 1.11 as we are using the mod support
* Thu Mar 14 2019 Marcus Rueckert <mrueckert@suse.de>
- Update to version 1.46:
  - New backends
  - Support Alibaba Cloud (Aliyun) OSS via the s3 backend (Nick Craig-Wood)
  - New commands
  - serve dlna: serves a remove via DLNA for the local network (nicolov)
  - New Features
  - copy, move: Restore deprecated --no-traverse flag (Nick Craig-Wood)
  - This is useful for when transferring a small number of files into a large destination
  - genautocomplete: Add remote path completion for bash completion (Christopher Peterson & Danil Semelenov)
  - Buffer memory handling reworked to return memory to the OS better (Nick Craig-Wood)
  - Buffer recycling library to replace sync.Pool
  - Optionally use memory mapped memory for better memory shrinking
  - Enable with --use-mmap if having memory problems - not default yet
  - Parallelise reading of files specified by --files-from (Nick Craig-Wood)
  - check: Add stats showing total files matched. (Dario Guzik)
  - Allow rename/delete open files under Windows (Nick Craig-Wood)
  - lsjson: Use exactly the correct number of decimal places in the seconds (Nick Craig-Wood)
  - Add cookie support with cmdline switch --use-cookies for all HTTP based remotes (qip)
  - Warn if --checksum is set but there are no hashes available (Nick Craig-Wood)
  - Rework rate limiting (pacer) to be more accurate and allow bursting (Nick Craig-Wood)
  - Improve error reporting for too many/few arguments in commands (Nick Craig-Wood)
  - listremotes: Remove -l short flag as it conflicts with the new global flag (weetmuts)
  - Make http serving with auth generate INFO messages on auth fail (Nick Craig-Wood)
  - Bug Fixes
  - Fix layout of stats (Nick Craig-Wood)
  - Fix --progress crash under Windows Jenkins (Nick Craig-Wood)
  - Fix transfer of google/onedrive docs by calling Rcat in Copy when size is -1 (Cnly)
  - copyurl: Fix checking of --dry-run (Denis Skovpen)
  - Mount
  - Check that mountpoint and local directory to mount don’t overlap (Nick Craig-Wood)
  - Fix mount size under 32 bit Windows (Nick Craig-Wood)
  - VFS
  - Implement renaming of directories for backends without DirMove (Nick Craig-Wood)
  - now all backends except b2 support renaming directories
  - Implement --vfs-cache-max-size to limit the total size of the cache (Nick Craig-Wood)
  - Add --dir-perms and --file-perms flags to set default permissions (Nick Craig-Wood)
  - Fix deadlock on concurrent operations on a directory (Nick Craig-Wood)
  - Fix deadlock between RWFileHandle.close and File.Remove (Nick Craig-Wood)
  - Fix renaming/deleting open files with cache mode “writes” under Windows (Nick Craig-Wood)
  - Fix panic on rename with --dry-run set (Nick Craig-Wood)
  - Fix vfs/refresh with recurse=true needing the --fast-list flag
  - Local
  - Add support for -l/--links (symbolic link translation) (yair@unicorn)
  - this works by showing links as link.rclonelink - see local backend docs for more info
  - this errors if used with -L/--copy-links
  - Fix renaming/deleting open files on Windows (Nick Craig-Wood)
  - Crypt
  - Check for maximum length before decrypting filename to fix panic (Garry McNulty)
  - Azure Blob
  - Allow building azureblob backend on *BSD (themylogin)
  - Use the rclone HTTP client to support --dump headers, --tpslimit etc (Nick Craig-Wood)
  - Use the s3 pacer for 0 delay in non error conditions (Nick Craig-Wood)
  - Ignore directory markers (Nick Craig-Wood)
  - Stop Mkdir attempting to create existing containers (Nick Craig-Wood)
  - B2
  - cleanup: will remove unfinished large files >24hrs old (Garry McNulty)
  - For a bucket limited application key check the bucket name (Nick Craig-Wood)
  - before this, rclone would use the authorised bucket regardless of what you put on the command line
  - Added --b2-disable-checksum flag (Wojciech Smigielski)
  - this enables large files to be uploaded without a SHA-1 hash for speed reasons
  - Drive
  - Set default pacer to 100ms for 10 tps (Nick Craig-Wood)
  - This fits the Google defaults much better and reduces the 403 errors massively
  - Add --drive-pacer-min-sleep and --drive-pacer-burst to control the pacer
  - Improve ChangeNotify support for items with multiple parents (Fabian Möller)
  - Fix ListR for items with multiple parents - this fixes oddities with vfs/refresh (Fabian Möller)
  - Fix using --drive-impersonate and appfolders (Nick Craig-Wood)
  - Fix google docs in rclone mount for some (not all) applications (Nick Craig-Wood)
  - Dropbox
  - Retry-After support for Dropbox backend (Mathieu Carbou)
  - FTP
  - Wait for 60 seconds for a connection to Close then declare it dead (Nick Craig-Wood)
  - helps with indefinite hangs on some FTP servers
  - Google Cloud Storage
  - Update google cloud storage endpoints (weetmuts)
  - HTTP
  - Add an example with username and password which is supported but wasn’t documented (Nick Craig-Wood)
  - Fix backend with --files-from and non-existent files (Nick Craig-Wood)
  - Hubic
  - Make error message more informative if authentication fails (Nick Craig-Wood)
  - Jottacloud
  - Resume and deduplication support (Oliver Heyme)
  - Use token auth for all API requests Don’t store password anymore (Sebastian Bünger)
  - Add support for 2-factor authentification (Sebastian Bünger)
  - Mega
  - Implement v2 account login which fixes logins for newer Mega accounts (Nick Craig-Wood)
  - Return error if an unknown length file is attempted to be uploaded (Nick Craig-Wood)
  - Add new error codes for better error reporting (Nick Craig-Wood)
  - Onedrive
  - Fix broken support for “shared with me” folders (Alex Chen)
  - Fix root ID not normalised (Cnly)
  - Return err instead of panic on unknown-sized uploads (Cnly)
  - Qingstor
  - Fix go routine leak on multipart upload errors (Nick Craig-Wood)
  - Add upload chunk size/concurrency/cutoff control (Nick Craig-Wood)
  - Default --qingstor-upload-concurrency to 1 to work around bug (Nick Craig-Wood)
  - S3
  - Implement --s3-upload-cutoff for single part uploads below this (Nick Craig-Wood)
  - Change --s3-upload-concurrency default to 4 to increase perfomance (Nick Craig-Wood)
  - Add --s3-bucket-acl to control bucket ACL (Nick Craig-Wood)
  - Auto detect region for buckets on operation failure (Nick Craig-Wood)
  - Add GLACIER storage class (William Cocker)
  - Add Scaleway to s3 documentation (Rémy Léone)
  - Add AWS endpoint eu-north-1 (weetmuts)
  - SFTP
  - Add support for PEM encrypted private keys (Fabian Möller)
  - Add option to force the usage of an ssh-agent (Fabian Möller)
  - Perform environment variable expansion on key-file (Fabian Möller)
  - Fix rmdir on Windows based servers (eg CrushFTP) (Nick Craig-Wood)
  - Fix rmdir deleting directory contents on some SFTP servers (Nick Craig-Wood)
  - Fix error on dangling symlinks (Nick Craig-Wood)
  - Swift
  - Add --swift-no-chunk to disable segmented uploads in rcat/mount (Nick Craig-Wood)
  - Introduce application credential auth support (kayrus)
  - Fix memory usage by slimming Object (Nick Craig-Wood)
  - Fix extra requests on upload (Nick Craig-Wood)
  - Fix reauth on big files (Nick Craig-Wood)
  - Union
  - Fix poll-interval not working (Nick Craig-Wood)
  - WebDAV
  - Support About which means rclone mount will show the correct disk size (Nick Craig-Wood)
  - Support MD5 and SHA1 hashes with Owncloud and Nextcloud (Nick Craig-Wood)
  - Fail soft on time parsing errors (Nick Craig-Wood)
  - Fix infinite loop on failed directory creation (Nick Craig-Wood)
  - Fix identification of directories for Bitrix Site Manager (Nick Craig-Wood)
  - Fix upload of 0 length files on some servers (Nick Craig-Wood)
  - Fix if MKCOL fails with 423 Locked assume the directory exists (Nick Craig-Wood)
* Mon Dec  3 2018 Ismail Dönmez <idonmez@suse.com>
- Update to version v1.45
  * See https://rclone.org/changelog/ for the complete changelog.
* Thu Sep 27 2018 Ismail Dönmez <idonmez@suse.com>
- Update to version v1.43.1
  * See https://rclone.org/changelog/ for the complete changelog.
- Switch to obs_scm
* Sat Jun 23 2018 asarai@suse.com
- Update to rclone v1.42.
  See https://rclone.org/changelog/ for changelog.
- Switch to %%license macro.
* Tue Jun  5 2018 jacobwinski@gmail.com
- Update to rclone v1.41.
  * Too many changes to list, please see
    https://rclone.org/changelog/ for the complete changelog.
* Tue Jun  5 2018 jacobwinski@gmail.com
- Fix spec file causing build error (unresolvable) on Leap 42.3.
* Fri Apr 13 2018 asarai@suse.com
- Update to rclone v1.40.
* Sat Jan 13 2018 asarai@suse.com
- Initial import of rclone v1.39, an rsync-like utility for cloud storage.
